/*
 * Copyright (C) 2009 Niek Linnenbank
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __CONFIG_H
#define __CONFIG_H

/**
 * @brief Static PIDS.
 * @{
 */

#define ANY		65535
#define SELF		65534
#define KERNEL_PID	65533

#define PROCSRV_PID	0
#define VFSSRV_PID	1
#define MEMSRV_PID	2
#define DEVSRV_PID	3
#define LOGSRV_PID	4

/**
 * @}
 */

#endif /* __CONFIG_H */
